@@ -206,18 +206,27 @@ class CliMixin(BaseComponent):  # pylint: disable=too-many-ancestors
 
         with self.extra():
             aux = self.auxcon
-            cmd = ["sphinx-apidoc", "-o", aux.docs.root, aux.project.module_dir]
-            subprocess.run(cmd, check=True)
-            cmd = ["sphinx-build", "-M", "html", aux.docs.root, docs_cache]
-            if aux.docs.get("strict", True):
-                cmd.append("-W")
-            subprocess.run(cmd, check=True)
-            cmd = [
-                "python",
-                self.target / "docs" / "postprocess_html.py",
-                (docs_cache / "html" / aux.project.second_name).with_suffix(".html"),
-            ]
-            subprocess.run(cmd, check=True)
+
+            if aux.docs.framework == "sphinx":
+                cmd = ["sphinx-apidoc", "-o", aux.docs.root, aux.project.module_dir]
+                subprocess.run(cmd, check=True)
+                cmd = ["sphinx-build", "-M", "html", aux.docs.root, docs_cache]
+                if aux.docs.get("strict", True):
+                    cmd.append("-W")
+                subprocess.run(cmd, check=True)
+                cmd = [
+                    "python",
+                    self.target / "docs" / "postprocess_html.py",
+                    (docs_cache / "html" / aux.project.second_name).with_suffix(
+                        ".html"
+                    ),
+                ]
+                subprocess.run(cmd, check=True)
+            elif aux.docs.framework == "mkdocs":
+                cmd = ["mkdocs", "build", "-f", f"{aux.docs.root}/mkdocs.yml"]
+                subprocess.run(cmd, check=True)
+            else:
+                raise NotImplementedError(aux.docs.framework)
 
         if open_html:
             cmd = ["open", docs_cache / "html" / "index.html"]
