@@ -1,5 +1,6 @@
 # Copyright (c) 2021-2023 Mario S. Könz; License: MIT
 # pylint: disable=too-many-lines
+import collections
 import contextlib
 import typing as tp
 
@@ -79,6 +80,10 @@ class DockerMixin(DependencyMixin, ProjectMixin):
                 yield auxcone
                 return
             data.services = self.list2ns(data.services)
+            data.setdefault("base_match", {})
+            data.base_match = collections.OrderedDict(
+                (key, _ProtoNamespace(val)) for key, val in data.base_match.items()
+            )
             for key, opts in data.services.items():
                 if "extra_req" in opts:
                     opts["extra_req"] = opts["extra_req"].split(",")
@@ -102,6 +107,7 @@ class DockerMixin(DependencyMixin, ProjectMixin):
                 opts.setdefault("pip_req", [])
                 opts.setdefault("script", [])
                 opts.setdefault("base", None)
+                self._adjust_base_on_match_entry(opts, auxcone)
 
                 opts.setdefault("apt_req", [])
                 if "-" in key:
@@ -140,6 +146,28 @@ class DockerMixin(DependencyMixin, ProjectMixin):
             data.source_dir = f"../../{auxcone.project.source_dir}"
             yield auxcone
 
+    def _adjust_base_on_match_entry(
+        self,
+        opts: _ProtoNamespace,
+        auxcone: _ProtoNamespace,
+    ) -> None:
+        base_match = auxcone.docker.base_match
+        if opts.base is None:
+            return
+        image, tag = opts.base.rsplit(":", 1)
+        if image not in base_match:
+            return
+        fallback = base_match[image].fallback
+        var = (
+            f'{image.upper().replace("/", "_").replace(".", "_").replace("-", "_")}_TAG'
+        )
+        skip = [auxcone.gitlab.release_branch]
+
+        # changing this order affects the jinja2 files!
+        opts.base_match = [(image, var, skip, fallback, tag)]
+
+        opts.base = f"{image}:${var}"
+
     def bake(self) -> None:
         super().bake()
         data = self.auxcon.docker
