@@ -1,5 +1,6 @@
 # Copyright (c) 2021-2023 Mario S. Könz; License: MIT
-from ._03_meta import MetaMixin
+from ._03_0_meta import MetaMixin
+from ._03_1_monotonic_version import MonotonicVersionMixin
 from ._04_project import ProjectMixin
 from ._05_dependency import DependencyMixin
 from ._06_package import PackageMixin
@@ -37,6 +38,7 @@ class AllComponents(  # pylint: disable=too-many-ancestors
     GitlabMixin,
     GitIgnoreMixin,
     ProjectMixin,
+    MonotonicVersionMixin,
     MetaMixin,
 ):
     pass
