@@ -5,6 +5,16 @@ import typing as tp
 
 import requests
 
+__all__ = ["LazyVersionStr"]
+
+
+class LazyVersionStr:
+    def __str__(self) -> str:
+        # pylint: disable=import-outside-toplevel,cyclic-import
+        import adaux
+
+        return adaux.__version__
+
 
 @dc.dataclass
 class ApiRequestCommunicator:
